@@ -1,5 +1,4 @@
-from __future__ import absolute_import, unicode_literals
-
+import os
 from stat import S_IXGRP, S_IXOTH, S_IXUSR
 
 
@@ -17,4 +16,13 @@ def make_exe(filename):
             continue
 
 
-__all__ = ("make_exe",)
+def set_tree(folder, stat):
+    for root, _, files in os.walk(str(folder)):
+        for filename in files:
+            os.chmod(os.path.join(root, filename), stat)
+
+
+__all__ = (
+    "make_exe",
+    "set_tree",
+)
